Package: fritools
Title: Utilities for the Forest Research Institute of the State
        Baden-Wuerttemberg
Version: 4.6.0
Authors@R: 
    person(given = "Andreas Dominik",
           family = "Cullmann",
           role = c("aut", "cre"),
           email = "fvafrcu@mailbox.org")
Description: Miscellaneous utilities, tools and helper
    functions for finding and searching files on disk, searching for and
    removing R objects from the workspace.
    Does not import or depend on any third party package, but on core R 
    only (i.e. it may depend on packages with priority 'base').
License: BSD_2_clause + file LICENSE
URL: https://gitlab.com/fvafrcu/fritools
Depends: R (>= 3.3.0)
Imports: methods, stats, utils
Suggests: callr, checkmate, covr, desc, devtools, digest, dplyr,
        microbenchmark, pkgload, reshape, rmarkdown, RUnit, testthat
        (>= 3.0.0), tinytest, whoami
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.3.3
VignetteBuilder: utils
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-02-17 20:03:26 UTC; qwer
Author: Andreas Dominik Cullmann [aut, cre]
Maintainer: Andreas Dominik Cullmann <fvafrcu@mailbox.org>
Repository: CRAN
Date/Publication: 2026-02-18 06:30:25 UTC
Built: R 4.6.0; ; 2026-04-25 10:29:42 UTC; unix
