# Generated by roxygen2: do not edit by hand

S3method(convert_umlauts_to_ascii,character)
S3method(convert_umlauts_to_ascii,data.frame)
S3method(convert_umlauts_to_utf8,character)
S3method(convert_umlauts_to_utf8,data.frame)
S3method(summary,filesearch)
S3method(weighted_variance,data.frame)
S3method(weighted_variance,numeric)
export(bulk_read_csv)
export(bulk_write_csv)
export(call_conditionally)
export(call_safe)
export(char2factor)
export(check_ascii_file)
export(clipboard_path)
export(column_sums)
export(compare_vectors)
export(convert_from_power_of_ten)
export(convert_to_power_of_ten)
export(convert_umlauts_to_ascii)
export(convert_umlauts_to_tex)
export(convert_umlauts_to_utf8)
export(count_groups)
export(csv2csv)
export(delete_trailing_blank_lines)
export(delete_trailing_whitespace)
export(develop_test)
export(df_from_powers_of_ten)
export(df_to_powers_of_ten)
export(escape_non_ascii)
export(file_copy)
export(file_modified_last)
export(file_save)
export(file_string)
export(find_files)
export(find_missing_family)
export(find_missing_see_also)
export(fromto)
export(get_boolean_envvar)
export(get_german_umlauts)
export(get_lines_between_tags)
export(get_mtime)
export(get_options)
export(get_package_version)
export(get_path)
export(get_r_cmd_batch_script_path)
export(get_rscript_script_path)
export(get_run_r_tests)
export(get_script_name)
export(get_script_path)
export(get_session_string)
export(get_unique_string)
export(golden_ratio)
export(grep_file)
export(index_groups)
export(is_batch)
export(is_cran)
export(is_difftime_less)
export(is_false)
export(is_files_current)
export(is_force)
export(is_installed)
export(is_not_false)
export(is_null_or_true)
export(is_of_length_zero)
export(is_path)
export(is_r_cmd_check)
export(is_r_package_installed)
export(is_running_on_fvafrcu_machines)
export(is_running_on_gitlab_com)
export(is_scalar)
export(is_scalar_convertible2numeric)
export(is_success)
export(is_true)
export(is_valid_primary_key)
export(is_version_sufficient)
export(is_windows)
export(load_internal_functions)
export(memory_hogs)
export(pause)
export(r_cmd_install)
export(read_csv)
export(relative_difference)
export(round_commercially)
export(round_half_away_from_zero)
export(rownames2col)
export(run_r_tests_for_known_hosts)
export(runsed)
export(search_files)
export(search_rows)
export(set_hash)
export(set_options)
export(set_path)
export(set_run_r_tests)
export(sloboda)
export(split_code_file)
export(str2num)
export(string2words)
export(strip_off_attributes)
export(subset_sizes)
export(tapply)
export(touch)
export(touch2)
export(un_hash)
export(view)
export(vim)
export(weighted_variance)
export(wipe_clean)
export(wipe_tempdir)
export(with_dir)
export(write_csv)
