[![pipeline status](https://gitlab.com/fvafrcu/fritools/badges/master/pipeline.svg)](https://gitlab.com/fvafrcu/fritools/-/commits/master)    
[![coverage report](https://gitlab.com/fvafrcu/fritools/badges/master/coverage.svg)](https://gitlab.com/fvafrcu/fritools/-/commits/master)
<!-- 
    [![Build Status](https://travis-ci.org/fvafrcu/fritools.svg?branch=master)](https://travis-ci.org/fvafrcu/fritools)
    [![Coverage Status](https://codecov.io/github/fvafrcu/fritools/coverage.svg?branch=master)](https://codecov.io/github/fvafrcu/fritools?branch=master)
-->
[![CRAN_Status_Badge](https://www.r-pkg.org/badges/version/fritools)](https://cran.r-project.org/package=fritools)
[![RStudio_downloads_monthly](https://cranlogs.r-pkg.org/badges/fritools)](https://cran.r-project.org/package=fritools)
[![RStudio_downloads_total](https://cranlogs.r-pkg.org/badges/grand-total/fritools)](https://cran.r-project.org/package=fritools)

<!-- README.md is generated from README.Rmd. Please edit that file -->



# fritools
## Introduction

After installation, please read the help page:

```r
help("fritools-package", package = "fritools")
```


```
#> Utilities for the Forest Research Institute of the State
#> Baden-Wuerttemberg
#> 
#> Description:
#> 
#>      Miscellaneous utilities, tools and helper functions.
#> 
#> Details:
#> 
#>      You will find the details in
#>      'vignette("Not_an_Introduction_to_fritools", package =
#>      "fritools")'.
#> 
#> Author(s):
#> 
#>      *Maintainer*: Andreas Dominik Cullmann
#>      <mailto:fvafrcu@mailbox.org>
#> 
#> See Also:
#> 
#>      Useful links:
#> 
#>         • <https://gitlab.com/fvafrcu/fritools>
```

## Installation

You can install fritools from gitlab via:


```r
if (! require("remotes")) install.packages("remotes")
remotes::install_gitlab("fvafrcu/fritools")
```


