#' Utilities for the Forest Research Institute of the State
#' Baden-Wuerttemberg
#'
#' Miscellaneous utilities, tools and helper functions.
#'
#' You will find the details in\cr
#' \code{vignette("Not_an_Introduction_to_fritools", package = "fritools")}.
#'
#' @name fritools-package
#' @aliases fritools-package
#' @docType package
#' @keywords package
NULL
